@@ -1,5 +1,5 @@
 package Mira::Control::Content::Address;
-$Mira::Control::Content::Address::VERSION = '00.07.36';
+$Mira::Control::Content::Address::VERSION = '00.07.37';
 
 use strict;
 use warnings;
@@ -131,6 +131,11 @@ sub address {
         $self->{$utid}->{url} = $permalink;
         $self->{$utid}->{url} =~ s{(?<!:)/+}{/}g;
 
+        $self->{$utid}->{furl} = $self->{$utid}->{url};
+        my $furl = qr{^$baseurl};
+        my $fpath = $config->{$floor}->{url};
+        $self->{$utid}->{furl} =~ s/$furl/$fpath/ if $config->{$floor}->{root};
+
     }    #end foreach utid;
 
 }
